==> haskell-hspec-core-2.7.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.7.1
id: hspec-core-2.7.1-GAgVZAe5BD33FzKgl8b1M
key: hspec-core-2.7.1-GAgVZAe5BD33FzKgl8b1M
license: MIT
copyright: (c) 2011-2019 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
abi: bac8433ad801b1eed0cb1f5adac4ab03
exposed: True
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Clock Test.Hspec.Core.Compat
                Test.Hspec.Core.Config Test.Hspec.Core.Config.Options
                Test.Hspec.Core.Config.Util Test.Hspec.Core.Example
                Test.Hspec.Core.Example.Location Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Format Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Control.Concurrent.Async
                Data.Algorithm.Diff Paths_hspec_core
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-core-2.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-core-2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-core-2.7.1
hs-libraries: HShspec-core-2.7.1-GAgVZAe5BD33FzKgl8b1M
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X array-0.5.3.0
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    clock-0.8-H1S1zDefxirImaRbI6ITNv deepseq-1.4.4.0 directory-1.3.3.0
    filepath-1.4.2.1 hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    quickcheck-io-0.2.0-Gntr2T9Vy6n1IMUVJ9zBpG
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz stm-2.5.0.0
    tf-random-0.5-IjFVdJXpGgq3hBuRJiaT27 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.7.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.7.1
id: hspec-core-2.7.1-885e7phFBQnJ4twaYTfwQ5
key: hspec-core-2.7.1-885e7phFBQnJ4twaYTfwQ5
license: MIT
copyright: (c) 2011-2019 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
abi: f10a0e4be05a7d1fba27e0f1dc436244
exposed: True
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Clock Test.Hspec.Core.Compat
                Test.Hspec.Core.Config Test.Hspec.Core.Config.Options
                Test.Hspec.Core.Config.Util Test.Hspec.Core.Example
                Test.Hspec.Core.Example.Location Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Format Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Control.Concurrent.Async
                Data.Algorithm.Diff Paths_hspec_core
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-core-2.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-core-2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-core-2.7.1
hs-libraries: HShspec-core-2.7.1-885e7phFBQnJ4twaYTfwQ5
depends:
    HUnit-1.6.0.0-JbqplLUCHWj8gC9WuQWK9
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    base-4.12.0.0 call-stack-0.2.0-7kE9ck8b3cWExm7jAiSNAI
    clock-0.8-H1S1zDefxirImaRbI6ITNv deepseq-1.4.4.0 directory-1.3.3.0
    filepath-1.4.2.1 hspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
    quickcheck-io-0.2.0-841cHQ09E7p9PTYzjmSoUF
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz stm-2.5.0.0
    tf-random-0.5-IjFVdJXpGgq3hBuRJiaT27 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
